### Name: water
### Title: Properties of Water
### Aliases: water water.AW90 water.IAPWS95 water.WP02 water.SUPCRT92
### Keywords: misc

### ** Examples

  ## Don't show: 
data(thermo)
## End Don't show
  ## set temperature, density
  T <- 500; rho <- 838.0235
  # calculate pressure                          
  P <- as.numeric(water.IAPWS95('P',T=T,rho=rho))
  # output table of test values
  water.IAPWS95('test') 
  # calculate dielectric constant       
  water.AW90(T=T,rho=rho,P=P)   
  # find water density for this T, P            
  water('rho',T=T,P=convert(P,'bar'))
  
  ## density along saturation curve
  T <- seq(273.15,623.15,25)
  water.WP02(T=T)
  water.WP02('rho.vapor',T)                     
  water('rho',T=T,P='Psat')
  # values of the density, Psat, Gibbs energy   
  water(c('rho','psat','G'),T=T,P='Psat') 
  # derivatives of the inverse of dielectric
  # constant (Born functions)
  # water(c('Q','Y','X','U'),T=T)
  # now at constant pressure
  water(c('Q','Y','X','U'),T=T,P=2000)
  
  ## NaCl dissocation logK-T
  ## after Shock et al., 1992, Fig. 1
  s <- c('NaCl','Na+','Cl-')
  n <- c(-1,1,1)
  T <- seq(200,1000,25)
  P <- seq(1000,4000,500)
  t <- subcrt(s,n,T=T,P=P,grid='P')
  plot(t$out$T,t$out$logK,
      xlim=c(0,1000),ylim=c(-5.5,1),
      xlab=axis.label('T'),ylab='log K')
  title(main=paste('NaCl = Na+ + Cl-\n',
    '1000 - 4000 bar, after Shock et al., 1992'))

  ## comparing the the computational options
  prop <- c('A','G','S','U','H','Cv','Cp','w','epsilon',
    'Y','Q','X','rho','Psat')
  thermo$opt$water <- 'SUPCRT'
  print(water(prop,T=convert(c(25,100,200,300),'K')))
  thermo$opt$water <- 'IAPWS'
  print(water(c(prop,'N','UBorn'),T=convert(c(25,100,200,300),'K')))
  # fixme: things seem to be working except speed of
  # sound in our IAPWS calculations

  # calculating Q Born function
  # after Table 22 of Johnson and Norton, 1991
  thermo$opt$water <- 'SUPCRT'
  T <- rep(c(375,400,425,450,475),each=5)
  P <- rep(c(250,300,350,400,450),5)
  t <- water('Q',T=convert(T,'K'),P=P)
  # the rest to make a readable table
  t <- as.data.frame(matrix(t[[1]],nrow=5))
  colnames(t) <- T[1:5*5]
  rownames(t) <- P[1:5]
  print(t)



